import { MessageContextCard } from "@/components/cards/MessageContextCard";
import { UserCard } from "@/components/cards/UserCard";
import { Avatar, AvatarImage, AvatarFallback } from "@/components/ui/avatar";
import { Badge } from "@/components/ui/badge";
import { Button, buttonVariants } from "@/components/ui/button";
import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover";
import { Separator } from "@/components/ui/separator";
import {
  fetchReportById,
  fetchSnapshotsByReport,
  fetchUserById,
} from "@/lib/db";
import { ArrowLeft } from "lucide-react";
import Link from "next/link";
import { Fragment } from "react";

export default async function Reports({ params }: { params: { id: string } }) {
  const report = await fetchReportById(params.id);
  if (!report) return <span>404</span>;

  const author = await fetchUserById(report.author_id);
  const snapshots = await fetchSnapshotsByReport(report._id);

  return (
    <div className="flex flex-col gap-2">
      <Link
        className={buttonVariants({ variant: "outline", size: "icon" })}
        href="/panel/reports"
      >
        <ArrowLeft className="h-4 w-4" />
      </Link>

      <Card className="shadow-none">
        <CardHeader>
          <CardTitle className="overflow-ellipsis whitespace-nowrap overflow-x-clip flex gap-2 items-center">
            {report.content.report_reason.includes("Illegal") && (
              <Badge variant="destructive">Urgent</Badge>
            )}{" "}
            {report.additional_context || "No reason specified"}
          </CardTitle>
          <CardDescription>
            {report._id.toString().substring(20, 26)} &middot;{" "}
            {report.content.report_reason} &middot; {report.content.type}
          </CardDescription>
        </CardHeader>
      </Card>
      <UserCard user={author!} subtitle="Report Author" />

      {snapshots.map((snapshot) => (
        <Fragment key={snapshot._id}>
          {/*<Separator />*/}
          <div className="flex gap-2">
            <div className="flex-[2]">
              {/*<h2 className="text-md">&nbsp;</h2>*/}
              {snapshot._type === "Message" && (
                <MessageContextCard snapshot={snapshot} />
              )}
            </div>
            <div className="flex-1">
              {/*<h2 className="text-md text-center">Related Open Reports</h2>*/}
            </div>
          </div>
        </Fragment>
      ))}
    </div>
  );
}
