import { Badge } from "@/components/ui/badge";
import {
  Card,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import { Input } from "@/components/ui/input";
import { fetchReports } from "@/lib/db";
import Link from "next/link";

export default async function Reports() {
  const reports = (await fetchReports()).sort((b, _) =>
    b.content.report_reason.includes("Illegal") ? -1 : 0
  );

  return (
    <div className="flex flex-col gap-2">
      <Input placeholder="Search for reports..." disabled />
      {reports.map((report) => (
        <Link href={`/panel/reports/${report._id}`} key={report._id as never}>
          <Card className="transition-all hover:-translate-y-1 hover:shadow-md">
            <CardHeader>
              <CardTitle className="overflow-ellipsis whitespace-nowrap overflow-x-clip flex gap-2 items-center">
                {report.content.report_reason.includes("Illegal") && (
                  <Badge variant="destructive">Urgent</Badge>
                )}{" "}
                {report.additional_context || "No reason specified"}
              </CardTitle>
              <CardDescription>
                {report._id.toString().substring(20, 26)} &middot;{" "}
                {report.content.report_reason} &middot; {report.content.type}
              </CardDescription>
            </CardHeader>
          </Card>
        </Link>
      ))}
    </div>
  );
}
